@@ -1,3 +1,4 @@
+from django.core.context_processors import csrf
 from django.db.models import Count, Sum
 from django.shortcuts import render_to_response
 from django.utils.decorators import method_decorator
@@ -5,6 +6,8 @@ from django.views.generic import View
 from silk.auth import login_possibly_required, permissions_possibly_required
 
 from silk.models import Profile, Request
+from silk.profiling.dynamic import _get_module
+from silk.request_filters import BaseFilter, filters_from_request
 
 
 class ProfilingView(View):
@@ -17,6 +20,10 @@ class ProfilingView(View):
                 'Time',
                 'Time on queries']
     defualt_order_by = 'Recent'
+    session_key_profile_filters = 'session_key_profile_filters'
+
+    def __init__(self, **kwargs):
+        super(ProfilingView, self).__init__(**kwargs)
 
     def _get_distinct_values(self, field, silk_request):
         if silk_request:
@@ -38,7 +45,9 @@ class ProfilingView(View):
     def _get_names(self, silk_request=None):
         return self._get_distinct_values('name', silk_request)
 
-    def _get_objects(self, show=None, order_by=None, name=None, func_name=None, silk_request=None):
+    def _get_objects(self, show=None, order_by=None, name=None, func_name=None, silk_request=None, filters=None):
+        if not filters:
+            filters = []
         if not show:
             show = self.default_show
         manager = Profile.objects
@@ -66,6 +75,9 @@ class ProfilingView(View):
             query_set = query_set.filter(func_name=func_name)
         if name:
             query_set = query_set.filter(name=name)
+        for f in filters:
+            query_set = f.contribute_to_query_set(query_set)
+            query_set = query_set.filter(f)
         return list(query_set[:show])
 
     def _create_context(self, request, *args, **kwargs):
@@ -80,6 +92,7 @@ class ProfilingView(View):
             show = int(show)
         func_name = request.GET.get('func_name', None)
         name = request.GET.get('name', None)
+        filters = request.session.get(self.session_key_profile_filters, {})
         context = {
             'show': show,
             'order_by': order_by,
@@ -89,7 +102,9 @@ class ProfilingView(View):
             'options_order_by': self.order_by,
             'options_func_names': self._get_function_names(silk_request),
             'options_names': self._get_names(silk_request),
+            'filters': filters
         }
+        context.update(csrf(request))
         if silk_request:
             context['silk_request'] = silk_request
         if func_name:
@@ -100,11 +115,20 @@ class ProfilingView(View):
                                  order_by=order_by,
                                  func_name=func_name,
                                  silk_request=silk_request,
-                                 name=name)
+                                 name=name,
+                                 filters=[BaseFilter.from_dict(x) for _, x in filters.items()])
         context['results'] = objs
         return context
 
     @method_decorator(login_possibly_required)
     @method_decorator(permissions_possibly_required)
+
     def get(self, request, *args, **kwargs):
         return render_to_response('silk/profiling.html', self._create_context(request, *args, **kwargs))
+
+    @method_decorator(login_possibly_required)
+    @method_decorator(permissions_possibly_required)
+    def post(self, request):
+        filters = filters_from_request(request)
+        request.session[self.session_key_profile_filters] = {ident: f.as_dict() for ident, f in filters.items()}
+        return render_to_response('silk/profiling.html', self._create_context(request))
